program HifiButton;

{---------------------------------------------------------------------
Example application for the custom control HifiButton (HifiBtns.DLL) of
the SMWCC 2.0 Custom Control Pack

Copyright (C) by Sebastian Modersohn

Note: This code file isn't documented into detail. If you have
      questions to *THIS* code file or want to know some details
      please contact me via CompuServe, ID 100340,1474.
---------------------------------------------------------------------}

{$R HBtnApp}

uses WinTypes, WinProcs, OWindows, ODialogs, Strings, BWCC,
     {the import unit for the button and its constant unit}
     HifiBtn, HBtnCo;

{for loading the DLL}
const DLLName        ='HifiBtns.DLL';
      em_DLLNotFound =1;

type
  PHifiBtnWindow = ^THifiBtnWindow;
  THifiBtnWindow = object(TDlgWindow)
    HBtn1, HBtn2, HBtn3: PHifiBtn;
    constructor Init(AParent: PWindowsObject; AName: PChar);

    procedure Change(var Msg: TMessage);
      virtual id_First + 301;
    procedure None(var Msg: TMessage);
      virtual id_First + 204;

    procedure Help(var Msg: TMessage);
      virtual id_First + idHelp;
  end;

{App that loads and frees the DLL and initializes the main window}
  PHifiBtnApp = ^THifiBtnApp;
  THifiBtnApp = object(TApplication)
    Lib: THandle;
    constructor Init(AName: PChar);
    destructor Done; virtual;
    procedure InitMainWindow; virtual;
    procedure Error(ErrorCode: Integer); virtual;
  end;

{ THifiBtnWindow }

constructor THifiBtnWindow.Init(AParent: PWindowsObject; AName: PChar);
begin
  inherited Init(AParent, AName);
  {Inits the Button}
  HBtn1:=New(PHifiBtn, InitResource(@Self, 201));
  HBtn2:=New(PHifiBtn, InitResource(@Self, 202));
  HBtn3:=New(PHifiBtn, InitResource(@Self, 203));
  {the button is normally disposed by the destructor of the parent}
end;

{change the LED-state of the three HifiButtons}
procedure THifiBtnWindow.Change(var Msg: TMessage);
begin
  HBtn1^.SetLight(not HBtn1^.GetLight);
  HBtn2^.SetLight(not HBtn2^.GetLight);
  HBtn3^.SetLight(not HBtn3^.GetLight);
end;

{the HifiButton "None" was clicked}
procedure THifiBtnWindow.None(var Msg: TMessage);
begin
  MessageBeep(0);
  MessageBox(HWindow, 'Clicked on ''None''-Button!', 'Click', mb_Ok or mb_IconInformation);
end;

procedure THifiBtnWindow.Help(var Msg: TMessage);
begin
  WinHelp(HWindow, HelpFile, Help_Context, 100);
end;

{ THifiBtnApp }

constructor THifiBtnApp.Init(AName: PChar);
begin
  {Load the library}
  Lib := LoadLibrary(DLLName);
  {If it wasn't loaded succesfully, then call error with em_DLLNotFound}
  if Lib < 32 then
    Status := em_DLLNotFound
  else
    inherited Init(AName);
end;

destructor THifiBtnApp.Done;
begin
  inherited Done;
  {Free the library}
  FreeLibrary(Lib);
end;

procedure THifiBtnApp.InitMainWindow;
begin
  MainWindow := New(PHifiBtnWindow, Init(nil, 'dlg_main'));
end;

procedure THifiBtnApp.Error(ErrorCode: Integer);
begin
  case ErrorCode of
    em_DLLNotFound:
      begin
        {if the dll could not be loaded display the message and fail the app}
        MessageBox(0, DLLName + ' not found. Please make sure that Windows will found this file!', 'Hard error',
          mb_Ok or mb_IconStop);
        Halt(ErrorCode);
      end;
  else
    inherited Error(ErrorCode);
  end;
end;

var
  App: THifiBtnApp;

begin
  App.Init('HifiBtn Demo');
  App.Run;
  App.Done;
end.
